import { useState, useEffect } from 'react'
import { ScrollView } from '@tarojs/components'
import withLayout from '@/layout'
import { useSelector } from 'react-redux'
import { fetch } from '@/utils/request'
import { API_LIVE_LIST, API_VIDEO_LIST } from '@/constants/api'
import './index.scss'
import '@/assets/css/iconfont.css'
import VideoListItem from './components/VideoListItem/index'

export default withLayout((props) => {
  const { city } = props

  const [IsPull, setPull] = useState(false)
  const [CurrnetMenuId, setCurrnetMenuId] = useState('all')
  const [MenuList] = useState([
    { name: '全部', id: 'all' },
    { name: '预告', id: 'notice' },
    { name: '直播中', id: 'live' },
    { name: '新房推荐', id: 'new' },
    { name: '视频', id: 'video' }
  ])
  const [PullTimer, setPullTimer] = useState(null)
  // 全部或者新房的列表
  const [activityList, setActivityList] = useState([])
  // 预告与直播的列表
  const [liveList, setLiveList] = useState([])
  // 视频的列表
  const [videoList, setVideoList] = useState([])

  useEffect(() => {
    if (city?.id) {
      GetLiveList()
    }
  }, [city?.id, CurrnetMenuId])


  const GetLiveList = (params) => {
    if (['all', 'new'].indexOf(CurrnetMenuId) > -1) {
      // 全部与新房用的一个接口
      fetch({ url: API_LIVE_LIST, payload: { ...params, cityId: city.id }, spin: true }).then((res) => {
        setActivityList(res.records || [])
      })
    } else if (['notice', 'live'].indexOf(CurrnetMenuId) > -1) {
      // 预告与直播是虽然是同一个接口, 但是返回值字段不一样
      const process = 'notice' === CurrnetMenuId ? 1 : 2;
      fetch({ url: API_LIVE_LIST, payload: { ...params, cityId: city.id, process }, spin: true}).then((res) => {
        setLiveList(res.records || [])
      })
    } else {
      // 视频另外一个接口
      fetch({ url: API_VIDEO_LIST, payload: { ...params, cityId: city.id }, spin: true }).then((res) => {
        setVideoList(res.records || [])
      })
    }
  }

  const PageRefresh = () => { // 页面下拉刷新回调
    setPull(true)
  }

  useEffect(() => { // 下拉刷新触发
    if (IsPull) {
      clearTimeout(PullTimer)
      setPullTimer(setTimeout(() => {
        setPull(false)
      }, 2000))
    }
  }, [IsPull])

  const CutMenu = (id) => {
    return () => {
      if (id !== CurrnetMenuId) {
        setCurrnetMenuId(id)
      }
    }
  }

  return (
    <view className='Page Video flex-v'>

      <view className='Search'>
        <view>
          <text className='iconfont icon-sousuo'></text>
          <text>输入项目名称或直播标题</text>
        </view>
      </view>

      <view className='Menu'>
        <view className='flex-h'>
          {
            MenuList.map((item, index) => (
              <view key={`MenuItem-${index}`} className={CurrnetMenuId === item.id ? 'active' : ''}>
                <text onClick={CutMenu(item.id)}>{item.name}</text>
              </view>
            ))
          }
        </view>
      </view>

      <view className='flex-item'>
        <view>
          <ScrollView scroll-y refresher-enabled refresher-triggered={IsPull} onrefresherrefresh={PageRefresh} refresher-background='#f8f8f8'>
            <view className='PageContent'>
              {
                /* 全部 与 新房 */
                ['all', 'new'].indexOf(CurrnetMenuId) > -1 && activityList.map((item, index) => (
                  <view className='ListItem' key={`List-${index}`}>
                    <view>
                      <view>
                        <VideoListItem Data={item}></VideoListItem>
                      </view>
                    </view>
                  </view>
                ))
              }
              {
                /* 预告 与 直播 */
                ['notice', 'live'].indexOf(CurrnetMenuId) > -1 && activityList.map((item, index) => (
                  <view className='ListItem' key={`List-${index}`}>
                    <view>
                      <view>
                        <VideoListItem Data={item}></VideoListItem>
                      </view>
                    </view>
                  </view>
                ))
              }
              {
                /* 视频 */
                'video' === CurrnetMenuId && activityList.map((item, index) => (
                  <view className='ListItem' key={`List-${index}`}>
                    <view>
                      <view>
                        <VideoListItem Data={item}></VideoListItem>
                      </view>
                    </view>
                  </view>
                ))
              }

              {/* bottom */}
              <view className='PageBottom'>
                <text>已经到底了~</text>
              </view>
            </view>
          </ScrollView>
        </view>
      </view>

    </view>
  )
})
